function nu=kinvisc(temp)
%KINVISC  Water kinematic viscosity as a function of the temperature.
%   
%   nu = KINVISC(T) returns the kinematic viscosity of water (in mm^2/s)
%   for a given temperature T (in deg. C), between 15 and 50 deg. C.
%   
%   KINVISC uses a 3rd order polynomial fit, with a precision of 0.5%.
%   
%   Example: plot(20:40,kinvisc(20:40))
%   
%   F. Moisy
%   Revision: 1.01,  Date: 2005/07/27
%
%   See also KINVISC_RHOD47.  


% History:
% 2003/02/01: v1.00, first version.
% 2005/07/27: v1.01, cosm.

if ((temp>=15)&(temp<=50)),
	nu=1.65597 - 0.042232*temp + 0.00053653*temp.^2 - 2.6459e-6*temp.^3;
else
	nu=NaN;
end;

