function nu=kinvisc_rhod47(nu0,temp)
%KINVISC_RHOD47  Kinematic viscosity of Rhodorsil 47 silicon oils
%
%   nu = KINVISC_RHOD47(nu0,temp) returns the kinematic viscosity of
%   Rhodorsil 47 silicon oil of nominal viscosity nu0 (at 25 deg. C) for a 
%   given temperature temp (between 0 and 100 deg. C). nu is in mm^2/s.
%   
%   KINVISC_RHOD47 is based on a 5-parameters fit from the reference
%   document provided by Rhodorsil.
%   
%   KINVISC_RHOD47(nu0,25) returns nu0. 
%
%   Example: plot(20:40,kinvisc_rhod47(100,20:40))
%  
%   F. Moisy
%   Revision: 1.01,  Date: 2005/07/27
%
%   See also KINVISC_RHOD47.  


% History:
% 2003/10/01: v1.00, first version.
% 2005/07/27: v1.01, cosm.


if ((temp>=0)&(temp<=100)),
    alpha=8.0187e-1;
    beta=-1.4264e-3;
    gamma=2.3961e-6;
    z=0.02116618;
    n=0.88691;
    theta=temp-25;
    x=alpha*theta + beta*theta.^2 + gamma*theta.^3;
    nu=exp((1+log(nu0))*exp(-z*((1+log(nu0))^(-n))*x)-1);
else
	nu=NaN;
end;

